clear all
% written by Laurinne Balstad and Allison Shaw, Contact ashaw@umn.edu for assistance.

a_r = 0.35;    % Max death, residents, 0 < a_r < 1
a_m = 0.47;    % Max death, migrants, a_r < a_m < 1
c_r = 0.85;   % Midpoint for logistic curve of death, residents, 0 < c_r < 1
c_m = 0.78;   % Midpoint for logistic curve of death, migrants, 0 < c_m < c_r
D = 54;        % Slope of logistic death cost, 0 < D
f_r = 0.85;    % Slope of birth cost, residents, 0 < f_r < B_{max}
f_m = 2.02;    % Slope of birth cost, migrants, f_r < f_m <B_{max}
B_max = 2.83;  % Intercept of birth cost, 0 < B_{max}
tauvec = linspace(0,2,1001);   % Steepness of infection curve, 0 < tau

t0vec = linspace(0,1,1001); % Initial time, 0 < t_0 < t_r
when_to_migrate1 = NaN(length(tauvec),length(t0vec));


for i = 1:length(t0vec)
    t_0 = t0vec(i);
    t_r = 1 - t_0;        % Time of resident’s second death/birth, 0 < t_r < 1
    I_0 = t_0./(t_0+tauvec); % Intensity at migration decision
    I_r = (t_0 + t_r)./(t_0 + t_r + tauvec); % Intensity of residents at end
    I_m = I_0;          % Intensity of migrants at end

    S_r_t0 = 1 - a_r./(1+ exp(-D*(I_0-c_r)) ); % Survival: S(a, c, D; I) = 1-{\frac{a}{1-e^{-D(I-c)}}}
    S_m_t0 = 1 - a_m./(1+ exp(-D*(I_0-c_m)) );
    S_r_tr = 1 - a_r./(1+ exp(-D*(I_r-c_r)) );
    S_m_tr = 1 - a_m./(1+ exp(-D*(I_m-c_m)) );
    S_r = S_r_t0.*S_r_tr;
    S_m = S_m_t0.*S_m_tr;

    b_r = -f_r*I_r + B_max; % Fecundity:  b(f, B_{max}; I) = -f(I) + B_{max}
    b_m = -f_m*I_m + B_max;

    fit_m = S_m.*b_m; % fitness of migrants
    fit_r = S_r.*b_r; % fitness of residents
    when_to_migrate1(:,i) = fit_m>fit_r;

    % check for both M and R shrinking
    ind = fit_m<1 & fit_r<1;
    when_to_migrate1(ind,i) = 2;

end

%% PART 2
t_0 = 0.2; % Initial time, 0 < t_0 < 1
    t_r = 1 - t_0;        % Time of resident’s second death/birth, 0 < t_r < 1
    I_0 = t_0./(t_0+tauvec); % Intensity at migration decision
    I_r = (t_0 + t_r)./(t_0 + t_r + tauvec); % Intensity of residents at end
    I_m = I_0;          % Intensity of migrants at end

    S_r_t0 = 1 - a_r./(1+ exp(-D*(I_0-c_r)) ); % Survival: S(a, c, D; I) = 1-{\frac{a}{1-e^{-D(I-c)}}}
    S_m_t0 = 1 - a_m./(1+ exp(-D*(I_0-c_m)) );
    S_r_tr = 1 - a_r./(1+ exp(-D*(I_r-c_r)) );
    S_m_tr = 1 - a_m./(1+ exp(-D*(I_m-c_m)) );
    S_r = S_r_t0.*S_r_tr;
    S_m = S_m_t0.*S_m_tr;

    b_r = -f_r*I_r + B_max; % Fecundity:  b(f, B_{max}; I) = -f(I) + B_{max}
    b_m = -f_m*I_m + B_max;

    fit_m = S_m.*b_m; % fitness of migrants
    fit_r = S_r.*b_r; % fitness of residents
  
%%

diff_fit = fit_m - fit_r;
diff_fit2 = diff_fit(1:100);
fx1 = tauvec(find(diff_fit>0,1,'first'));
fx2 = tauvec(find(diff_fit2>0,1,'last'));
fx3 = tauvec(find(diff_fit<0,1,'last'));

fs1 = 9;  % axes labels
fs3 = 9;  % axis numbering
lw2 = 1; % fig edges
lw1 = 1.5; % fig edges
msize = 10; % markersize

sx = 0.11;
sy = 0.27;
w1 = 0.2;
w2 = 0.55;
he = 0.66;
delx = 0.13;

figure(1); clf
hh = gcf;
set(hh,'PaperUnits','inches');
set(hh,'Units','inches');
width = 6; height = 2;
xpos = 5;
ypos = 4;
set(gcf,'Position',[xpos ypos width height])


cmap = [1   1   1;  % R, white
        0.8 0.8 0.8;% M, grey
        1   0.7  0.7] % dead = pint
gr = [0.6 0.6 0.6]; % shade of grey to use

axes('position',[sx sy w1 he])
    colormap(cmap)
    imagesc(t0vec,tauvec,when_to_migrate1)
    set(gca, 'YDir', 'normal')
    hold on
    temp = when_to_migrate1; temp(temp==2)=0;
    contour(t0vec,tauvec,temp,1,'color','k','LineWidth',lw1)
    ind = find(t0vec-t_0>0,1);
    line([t0vec(ind) t0vec(ind)],[0 tauvec(end)],'LineStyle',':','color','k','LineWidth',lw1)
    set(gca,'XTick',[0 0.5 1])
    set(gca,'YTick',[0 1 2])
    %xlabel('migration decision time (t_0)','fontsize',fs1)
    %ylabel('half infection time (t_h)','fontsize',fs1)
    set(gca,'FontSize',fs3,'LineWidth',lw2,'Fontname', 'Arial');

axes('position',[sx+delx+w1 sy w2 he])
    plot(tauvec,(b_m - b_r),'LineWidth',lw1)
    hold on
    plot(tauvec,(S_m - S_r),'LineWidth',lw1)
    line([fx1 fx1],[-1 1],'color',gr,'LineWidth',lw1,'HandleVisibility','off')
    line([fx2 fx2],[-1 1],'color',gr,'LineWidth',lw1,'HandleVisibility','off')
    line([fx3 fx3],[-1 1],'color',gr,'LineWidth',lw1,'HandleVisibility','off')
    plot(tauvec,zeros(1,length(tauvec)),'k','LineWidth',lw1,'HandleVisibility','off')
    legend('fecundity','survival','Location','SouthEast')
    axis([-0.01 1 -1 1])
    %xlabel('half infection time (t_h)','fontsize',fs1)
    ylabel({'difference in','fitness component'},'fontsize',fs1)
    set(gca,'FontSize',fs3,'LineWidth',lw2,'Fontname', 'Arial');

% labels
axes('position',[0 0 1 1],'visible','off')
hold on
     text(0   ,0.96,'a)','fontsize',fs3)
     text(0.33,0.96,'b)','fontsize',fs3)

     text(0.13,0.16,'early','horizontalalignment','center')
     text(0.29,0.16,'late','horizontalalignment','center')
     text(0.21,0.05,'migration point (t_0)','horizontalalignment','center')
     text(0.04,0.6,'half-intensity time (\tau_h)','horizontalalignment','center','rotation',90)
     text(0.07,0.85,'slow','horizontalalignment','center','rotation',90)
     text(0.07,0.32,'fast','horizontalalignment','center','rotation',90)
     
     text(0.44,0.88,'M<R','fontsize',fs3,'color',gr)
     text(0.49,0.88,'M>R','fontsize',fs3,'color',gr)
     text(0.59,0.88,'M<R','fontsize',fs3,'color',gr)
     text(0.79,0.88,'M>R','fontsize',fs3,'color',gr)

     text(0.75,0.05,'half-intensity time (\tau_h)','horizontalalignment','center')
     text(0.46,0.16,'fast','horizontalalignment','center')
     text(0.97,0.16,'slow','horizontalalignment','center')

axis([0 1 0 1])


% Backup previous settings
prePaperType = get(hh,'PaperType');
prePaperPosition = get(hh,'PaperPosition');
prePaperSize = get(hh,'PaperSize');

% Make changing paper type possible
set(hh,'PaperType','<custom>');
% Set the page size and position to match the figure's dimensions
position = get(hh,'Position');
set(hh,'PaperPosition',[0,0,position(3:4)]);
set(hh,'PaperSize',position(3:4));

%saveas(1,strcat(['fig.jpg']))
%print -dpdf -r600 Figure.pdf
print -djpeg -r600 fig3.jpg
print -dtiff -r600 fig3.tiff

% Restore the previous settings
set(hh,'PaperType',prePaperType);
set(hh,'PaperPosition',prePaperPosition);
set(hh,'PaperSize',prePaperSize);

