clear all
% written by Laurinne Balstad and Allison Shaw, Contact ashaw@umn.edu for assistance.

load output_fig4.mat
    f = 1; % these are scaling factors: should be at 1 here
    g = 1;
    x = 0:0.01:t0vec(end); % set up the contour plot with the mesh grid
    y = 0:0.01:tauvec(end);
    [X, Y] = meshgrid(x, y); % below is the equation contour
    Zb = ((1 - (a_m./(1 + exp(-D* (-c_m + (f.*(X)./((f.*(X))+(g.*(Y))))))))).^2).* (-f_m.* (f.*(X)./((f.*(X))+(g.*(Y)))) + B_max) - (1 - (a_r./(1 + exp(-D* (-c_r+ (1./(1 + g.*(Y)))))))).* (1 - (a_r./(1 + exp(-D* (-c_r+ (f.*(X)./((f.*(X))+(g.*(Y))))))))).* (-f_r* (1./(1 + g.*(Y))) + B_max);
    % check for any non-viable population sizes
    i1=isnan(M); sum(sum(i1))

% define color maps
cmap1 = colormap(flipud(gray));
xx=colormap(parula);
cmap2 =  [1 1 1; % white
        xx(55,:); % orange-yellow
        xx(6,:)]; % dark blue

fs1 = 9;  % axes labels
fs3 = 9;  % axis numbering
lw2 = 1; % fig edges
lw1 = 1.5; % fig edges
sx = 0.11;
sy = 0.27;
w1 = 0.2;
w2 = 0.48;
he = 0.66;
delx = 0.2;

%%
figure(1); clf
hh = gcf;
set(hh,'PaperUnits','inches');
set(hh,'Units','inches');
width = 6; height = 2;
xpos = 5;
ypos = 4;
set(gcf,'Position',[xpos ypos width height])

axes('position',[sx sy w1 he])
    colormap(cmap1)
    imagesc(t0vec, tauvec, M) % and put a color map of M in it --> yellow = full migration, dark blue = full residing
    set(gca, 'YDir', 'normal')
    hold on
    contour(X, Y, Zb, [0, 0],'linecolor', 'k','LineWidth',lw1) % add the contour on top
    hold off;
    set(gca,'XTick',[0.01 0.51 0.96])
    %plot line for panel b
    ind = find(t0vec-t0>0,1);
    line([t0vec(ind) t0vec(ind)],[0 tauvec(end)],'LineStyle',':','color','k','LineWidth',lw1)
    %colorbar
    set(gca,'FontSize',fs3,'LineWidth',lw2,'Fontname', 'Arial');
    freezeColors

% add colorbar by hand
axes('position',[sx+0.225 sy 0.02 he])
    imagesc([64:-1:1]')
    set(gca,'XTick',[])
    set(gca,'YTick',[])

    freezeColors

axes('position',[sx+delx+w1 sy w2 he])
    colormap(cmap2)
    imagesc(tauvec,1:1:10, ColMeansMat.',[-0.5 1])
    set(gca, 'YDir', 'normal')
    %set(gca,'YTick',[1 5 10])
    %ylabel('intensity class','fontsize',fs1)
    %xlabel('half infection time (t_h)','fontsize',fs1)
    set(gca,'FontSize',fs3,'LineWidth',lw2,'Fontname', 'Arial');

% labels
axes('position',[0 0 1 1],'visible','off')
    hold on
     text(0   ,0.96,'a)','fontsize',fs3)
     text(0.41,0.96,'b)','fontsize',fs3)
%    text(0.45,0.96,'b)','fontsize',fs3)

    text(0.13,0.16,'early','horizontalalignment','center')
    text(0.29,0.16,'late','horizontalalignment','center')
    text(0.21,0.05,'migration point (t_0)','horizontalalignment','center')
    text(0.04,0.6,'half-intensity time (\tau_h)','horizontalalignment','center','rotation',90)
    text(0.07,0.85,'slow','horizontalalignment','center','rotation',90)
    text(0.07,0.32,'fast','horizontalalignment','center','rotation',90)

    text(0.36,0.93,'1','fontsize',fs3)
    text(0.36,0.82,'0.8','fontsize',fs3)
    text(0.36,0.67,'0.6','fontsize',fs3)
    text(0.36,0.53,'0.4','fontsize',fs3)
    text(0.36,0.4,'0.2','fontsize',fs3)
    text(0.36,0.28,'0','fontsize',fs3)
    
    text(0.81,0.86       ,'always migrate','fontsize',fs3)
    text(0.81,0.86-0.07  ,'never migrate','fontsize',fs3)
    text(0.81,0.86-2*0.07,'NA','fontsize',fs3)
    annotation('rectangle',[0.79 0.835 0.012 0.04],'Color','w','FaceColor',xx(6,:))
    annotation('rectangle',[0.79 0.765 0.012 0.04],'Color','w','FaceColor',xx(55,:))
    annotation('rectangle',[0.78 0.68  0.20  0.22],'Color','k','LineWidth',lw2)
    
    text(0.43,0.6,'intensity class','horizontalalignment','center','rotation',90)
    text(0.46,0.85,'high','horizontalalignment','center','rotation',90)
    text(0.46,0.32,'low','horizontalalignment','center','rotation',90)
    text(0.75,0.05,'half-intensity time (\tau_h)','horizontalalignment','center')
    text(0.53,0.16,'fast','horizontalalignment','center')
    text(0.97,0.16,'slow','horizontalalignment','center')

axis([0 1 0 1])


% Backup previous settings
prePaperType = get(hh,'PaperType');
prePaperPosition = get(hh,'PaperPosition');
prePaperSize = get(hh,'PaperSize');

% Make changing paper type possible
set(hh,'PaperType','<custom>');
% Set the page size and position to match the figure's dimensions
position = get(hh,'Position');
set(hh,'PaperPosition',[0,0,position(3:4)]);
set(hh,'PaperSize',position(3:4));

%saveas(1,strcat(['fig.jpg']))
%print -dpdf -r600 Figure.pdf
print -djpeg -r600 fig4.jpg
print -dtiff -r600 fig4.tiff

% Restore the previous settings
set(hh,'PaperType',prePaperType);
set(hh,'PaperPosition',prePaperPosition);
set(hh,'PaperSize',prePaperSize);

