clear all
% written by Laurinne Balstad and Allison Shaw, Contact ashaw@umn.edu for assistance.

a_r = 0.44;    % Max death, residents, 0 < a_r < 1
a_m = 0.71;    % Max death, migrants, a_r < a_m < 1
c_r = 0.39;   % Midpoint for logistic curve of death, residents, 0 < c_r < 1
c_m = 0.2;    % Midpoint for logistic curve of death, migrants, 0 < c_m < c_r
D = 6;         % Slope of logistic death cost, 0 < D
f_r = 0.8;      % Slope of birth cost, residents, 0 < s_r < B_{max}
f_m = 1.5;      % Slope of birth cost, migrants, s_r < s_m <B_{max}
B_max = 2;    % Intercept of birth cost, 0 < B_{max}


% FECUNDITY VS INTENSITY
Ivec = 0:0.1:1;
b_r = -f_r*Ivec + B_max; % Fecundity:  b(f, B_{max}; I) = -f(I) + B_{max}
b_m = -f_m*Ivec + B_max;

% SURVIVAL VS INTENSITY
Ivec = 0:0.1:1;
S_m = 1 - a_m./(1+ exp(-D*(Ivec-c_m)) ); % Survival: S(a, c, D; I) = 1-{\frac{a}{1-e^{-D(I-c)}}}
S_r = 1 - a_r./(1+ exp(-D*(Ivec-c_r)) );


fs1 = 10;  % axes labels
fs3 = 09;  % axis numbering
lw2 = 1; % fig edges
lw1 = 1.5; % fig edges

width = 9;
height = 10;
xpos = 3;
ypos = 2;
sx = 0.17;
sy = 0.1;
w = 0.63;
he = 0.37;
dy = 0.12;
msize = 20;

figure(1); clf
hh = gcf;
set(hh,'PaperUnits','centimeters');
set(hh,'Units','centimeters');
set(gcf,'Position',[xpos ypos width height])

axes('position',[sx sy+dy+he w he])
    plot(Ivec,b_r,'-',Ivec,b_m,'--','LineWidth',lw1)
    c=get(gca,'colororder');
    hold on
    plot(1,b_r(end),'.','MarkerSize',msize,'color',c(1,:))
    plot(1,b_m(end),'.','MarkerSize',msize,'color',c(2,:))
    xlabel('intensity','fontsize',fs1)
    ylabel('fecundity','fontsize',fs1)
    legend('residents','migrants','Location','SouthWest')
    ylim([0 2])
    set(gca,'YTick',[0])
    set(gca,'FontSize',fs3,'LineWidth',lw2,'Fontname', 'Arial');

axes('position',[sx sy w he])
    S0 = 1 - a_m/2;
    delta = 0.05;
    line([c_m c_m],[0 S0],'LineStyle',':','color','k','LineWidth',lw2)
    hold on
    line([0 1],[1-a_r 1-a_r],'LineStyle',':','color','k','LineWidth',lw2)
    line([0 1],[1-a_m 1-a_m],'LineStyle',':','color','k','LineWidth',lw2)
    plot(Ivec,S_r,'-',Ivec,S_m,'--','LineWidth',lw1)
    plot(c_m,S0,'.','MarkerSize',msize,'color',c(2,:))
    set(gca,'YTick',[0 1])
    box on
    xlabel('intensity','fontsize',fs1)
    ylabel('survival','fontsize',fs1)
    set(gca,'FontSize',fs3,'LineWidth',lw2,'Fontname', 'Arial');

% label subpanels
axes('position',[0 0 1 1],'visible','off')
hold on
text(0.03,sy+2*he+dy,'a)','horizontalalignment','center')
text(0.03,sy+he,     'b)','horizontalalignment','center')

text(0.12,0.95,'B_{max}','horizontalalignment','center')
text(0.81,0.80,'B_{max} – f_r')
text(0.81,0.68,'B_{max} – f_m')
text(0.81,0.31,'1 – a_r')
text(0.81,0.20,'1 – a_m')
text(0.27,0.08,'c_m')
axis([0 1 0 1])


% Backup previous settings
prePaperType = get(hh,'PaperType');
prePaperPosition = get(hh,'PaperPosition');
prePaperSize = get(hh,'PaperSize');

% Make changing paper type possible
set(hh,'PaperType','<custom>');
% Set the page size and position to match the figure's dimensions
position = get(hh,'Position');
set(hh,'PaperPosition',[0,0,position(3:4)]);
set(hh,'PaperSize',position(3:4));

print -djpeg -r600 figS1.jpg

% Restore the previous settings
set(hh,'PaperType',prePaperType);
set(hh,'PaperPosition',prePaperPosition);
set(hh,'PaperSize',prePaperSize);



